@@ -9,6 +9,7 @@
 #include "chum.h"
 #include "theme.h"
 #include "composition_game_file_helper.h"
+#include "themeselection.h"
 
 static jammo_theme* current_theme; //One theme is handled at a time.
 
@@ -36,6 +37,9 @@ void composition_game_close(){
 	if (saving_dialog_cancel)
 		clutter_actor_show(saving_dialog_cancel);
 
+	ClutterActor* button_layer = jammo_get_actor_by_id("composition_game_buttons");
+	tangle_actor_hide_animated(TANGLE_ACTOR(button_layer));
+
 	ClutterActor* view = jammo_get_actor_by_id("compositiongame-view");
 
 	clutter_actor_show(CLUTTER_ACTOR(jammo_mentor_get_default())); /*This is needed when coming from cupboard, and mentor is hided*/
@@ -213,4 +217,7 @@ void composition_game_start_theme(const gchar* name, int variation, ClutterActor
 	ClutterActor* saving_dialog = jammo_get_actor_by_id("saving-dialog-view");
 	clutter_actor_raise_top(saving_dialog);
 	clutter_container_add(CLUTTER_CONTAINER(saving_dialog), current_theme->save_menu_container, NULL); //TODO: tangle_widget
+
+	ClutterActor* button_layer = jammo_get_actor_by_id("composition_game_buttons");
+	tangle_actor_show(TANGLE_ACTOR(button_layer));
 }
