@@ -31,7 +31,7 @@
 static JammoSequencer* singinggame_sequencer = NULL; //used for stopping
 
 
-static GList* songs;
+static GList* songs = NULL;
 
 
 
@@ -252,8 +252,14 @@ void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user
 
 
 static gboolean initialization_needed = TRUE;
+
 void singinggame_force_reinit_songs(){
-	initialization_needed = TRUE;
+	if (songs){
+		g_list_foreach (songs,(GFunc)song_free,NULL);
+		g_list_free(songs);
+	}
+	songs = song_init_songs_from_disk();
+	clutter_actor_hide(jammo_get_actor_by_id("wait"));
 }
 
 static void say_this_too(JammoMentor* mentor, const gchar*speech, gboolean interrupted, gpointer data){
@@ -269,18 +275,12 @@ static void say_this_too(JammoMentor* mentor, const gchar*speech, gboolean inter
 
 void singinggame_start_songselection(){
 	printf("Singinggame_start_songselection\n");
-	
-	//This is needed if used song packs are changed. i.e easy/advanced
-	if (initialization_needed)
-		songs = song_init_songs_from_disk();
 
 	gboolean first_time=initialization_needed; //only once after initialization textures are arrangent
 	initialization_needed=FALSE;
 
 	ClutterActor* container = jammo_get_actor_by_id("songselection-all-songs");
 
-		//clutter_container_foreach(CLUTTER_CONTAINER(container), clutter_actor_hide, NULL); //Are those also free'ed?
-
 	gfloat height_of_container=0;
 	const char* selected_language = chum_get_selected_language();
 
