@@ -28,7 +28,7 @@ gboolean start_communitymenu()
 	ClutterActor* mainview;
 
 	mainview = jammo_get_actor_by_id("main-views-widget");
-	clutter_container_foreach(CLUTTER_CONTAINER(mainview), chum_hide_this_tangle_actor, NULL);
+	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 
 
 	communitymenu_group = jammo_get_actor_by_id("communitymenu-view");
