@@ -39,7 +39,6 @@
 #include "midi_piano_roll.h"
 
 //STATICS
-static const ClutterColor red = { 255, 0, 0, 128 }; //for cursor
 static gfloat height_of_grid_slot = 64.0;  //non-zoomed grid-size (700px/64 = 11 slots.  400px/64= 6 slots)
 static gfloat width_of_grid_slot = 64.0;
 
@@ -47,7 +46,6 @@ static ClutterActor* static_piano_roll_in;   //zoomed_in version of piano_roll
 static ClutterActor* static_piano_roll_out;  //zoomed_out version of piano_roll
 
 static JammoSequencer* static_sequencer;
-static ClutterActor* static_cursor;
 
 //we got these as parameters and are returning them after use
 static JammoMiditrackView* static_jammo_miditrack_view; //Editor doesn't make own miditrack-view, but uses existing!
@@ -126,7 +124,8 @@ void midieditor_zoom_clicked  (TangleButton *tanglebutton, gpointer user_data)
 	jammo_miditrack_view_zoom_to_fit(static_jammo_miditrack_view,width, height);
 
 	//Cursor
-	clutter_actor_set_size(static_cursor, width, 180.0); //Area where cursor is moving.
+	ClutterActor* cursor = jammo_get_actor_by_id( "midieditor_cursor");
+	clutter_actor_set_size(cursor, width, 180.0); //Area where cursor is moving.
 }
 
 /**
@@ -181,7 +180,7 @@ void midieditor_exit_clicked  (TangleButton *tanglebutton, gpointer user_data)
 		exit(0);
 	}
 
-	jammo_sequencer_stop(static_sequencer);
+	//jammo_sequencer_stop(static_sequencer); //Do not automatically stop playing
 	//return miditrack-view to original parent and original attributes
 	ClutterActor* actor = CLUTTER_ACTOR(static_jammo_miditrack_view);
 	g_object_ref(actor);
@@ -208,8 +207,6 @@ void midieditor_exit_clicked  (TangleButton *tanglebutton, gpointer user_data)
 	//Delete piano_roll (actually its container and scroller and both piano-rolls)
 	clutter_actor_destroy(clutter_actor_get_parent(static_piano_roll_in));
 
-	//Cursor is generated each time.
-	clutter_actor_destroy(static_cursor);
 }
 
 
@@ -295,12 +292,9 @@ static void start_midi_editor(void) {
 
 
 	//Cursor
-	texture_for_cursor = clutter_rectangle_new_with_color(&red);
+	texture_for_cursor = jammo_get_actor_by_id( "midieditor_cursor_texture");
 	clutter_actor_set_size(texture_for_cursor, 10.0, height_of_grid_slot *(highest_note-lowest_note+1)); //Texture size
-	static_cursor = jammo_cursor_new(static_sequencer, texture_for_cursor);
-	tangle_actor_set_depth_position(TANGLE_ACTOR(static_cursor), 1);
-	clutter_actor_set_position(static_cursor, 0.0, 0.0);
-	clutter_actor_set_size(static_cursor, width_of_grid_slot*slots, 180.0); //Area where cursor is moving.
-	tangle_widget_add(TANGLE_WIDGET(container_for_track), static_cursor, NULL);
+	ClutterActor* cursor = jammo_get_actor_by_id( "midieditor_cursor");
+	clutter_actor_set_size(cursor, width_of_grid_slot*slots, 180.0); //Area where cursor is moving.
 }
 
