@@ -22,8 +22,6 @@ static ClutterActor* melodical_sample_looper;
 static ClutterActor* harmonical_sample_looper;
 static ClutterActor* effect_sample_looper;
 
-
-
 gboolean sequencer_lock_pressed (TangleButton* tanglebutton, gpointer data){
 
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
@@ -53,17 +51,9 @@ gboolean sequencer_lock_pressed (TangleButton* tanglebutton, gpointer data){
 
 
 /*
-Set dragging_threshold_y  of SampleButtons to MAXFLOAT. TODO: use template for them.
 ScrollingActor doesn't have clampping. This will set it.
 */
 static void fine_tune_wheel (ClutterActor* sample_looper) {
-
-	GList* children;
-	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(sample_looper)); children; children = children->next) {
-	tangle_draggable_actor_set_dragging_threshold_y (TANGLE_DRAGGABLE_ACTOR(children->data), G_MAXFLOAT); //DISABLE starting dragging vertically
-	}
-
-
 	ClutterActor* scrolling_actor = clutter_actor_get_parent(sample_looper);
 	g_signal_connect_swapped(scrolling_actor, "clamp-scrolling-offset-y", G_CALLBACK(tangle_widget_clamp_child_boundaries), sample_looper);
 }
@@ -160,8 +150,8 @@ static void rotate_loop_for_amount(ClutterActor* wheel, gint amount) {
 		if (threshold_y==10000.0) //means rolling is disabled for this wheel 
 			return;
 		gfloat offset = tangle_scrolling_actor_get_scrolling_offset_y(TANGLE_SCROLLING_ACTOR(scroller));
-		int current_slot = (int)(offset)/95; //round to lower slot, if rolling already
-		gfloat target = (current_slot+amount) * 95.0;
+		int current_slot = (int)(offset)/92; //round to lower slot, if rolling already
+		gfloat target = (current_slot+amount) * 92.0;
 		//printf("current_slot = %d, target pixel='%f'\n",current_slot,target);
 		clutter_actor_animate(CLUTTER_ACTOR(scroller), CLUTTER_EASE_IN_OUT_QUAD, 550, "scrolling-offset-y", target, NULL);
 	}
@@ -212,6 +202,7 @@ gboolean sequencer_handle_dragging (TangleDroppableActor *droppable_actor, Tangl
 
 
 void sequencer_loop_tune_wheels() {
+
 	//Static
 	rhytmical_sample_looper  =  jammo_get_actor_by_id("fullsequencer-loop-rhytmical-samples");
 	melodical_sample_looper  =  jammo_get_actor_by_id("fullsequencer-loop-melodical-samples");
