@@ -28,13 +28,19 @@ typedef struct {
  */
 enum {
 	INSTRUMENT_TRACK_VIEW = 1,
-	DRUM_TRACK_VIEW,
 	SLIDER_TRACK_VIEW,
 	AUDIO_TRACK_VIEW,
 	EDITING_TRACK_VIEW,
 	BACKING_TRACK_VIEW
 };
 
+//Types of editing track
+enum {
+	RHYTHM_TRACK,
+	MELODY_TRACK,
+	HARMONY_TRACK,
+	EFFECT_TRACK
+};
 
 void sequencer_track_view_create_area_for_tracks(JammoSequencer* seq, guint n_slots, guint64 total_duration, gfloat slot_width, gfloat height);
 ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean muted);
