@@ -10,6 +10,7 @@
 
 #include "jammo-sample-button.h"
 #include "jammo-track-view.h"
+#include "../meam/jammo-sequencer.h"
 #include <string.h>
 
 G_DEFINE_TYPE(JammoSampleButton, jammo_sample_button, TANGLE_TYPE_DRAGGABLE_ACTOR);
@@ -21,7 +22,8 @@ enum {
 	PROP_SAMPLE,
 	PROP_SAMPLE_TYPE,
 	PROP_LOOP_ID,
-	PROP_TEXT
+	PROP_TEXT,
+	PROP_SEQUENCER
 };
 
 enum {
@@ -34,6 +36,7 @@ struct _JammoSampleButtonPrivate {
 	JammoSample* sample;
 	JammoSampleType sample_type;
 	gint loop_id;
+	JammoSequencer* sequencer;
 };
 
 static const GEnumValue sample_type_values[] = {
@@ -59,6 +62,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 static gboolean on_clicked(TangleButton* button, gpointer user_data);
 static void on_size_change(ClutterTexture* texture, gint width, gint height, gpointer user_data);
+static void set_sequencer(JammoSampleButton* sample_button, JammoSequencer* sequencer);
 
 ClutterActor* jammo_sample_button_new() {
 
@@ -140,7 +144,7 @@ void jammo_sample_button_set_sample_filename(JammoSampleButton* sample_button, c
 		if (sample_button->priv->sample) {
 			g_object_unref(sample_button->priv->sample);
 		}
-		sample_button->priv->sample = jammo_sample_new_from_file(sample_filename);
+		sample_button->priv->sample = jammo_sample_new_from_file_with_sequencer(sample_filename, sample_button->priv->sequencer);
 		g_object_ref(sample_button->priv->sample);
 
 		g_object_notify(G_OBJECT(sample_button), "sample-filename");
@@ -279,6 +283,9 @@ static void jammo_sample_button_set_property(GObject* object, guint prop_id, con
 		case PROP_TEXT:
 			jammo_sample_button_set_text(sample_button, g_value_get_string(value));
 			break;
+		case PROP_SEQUENCER:
+			set_sequencer(sample_button, JAMMO_SEQUENCER(g_value_get_object(value)));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -320,6 +327,15 @@ static void jammo_sample_button_finalize(GObject* object) {
 }
 
 static void jammo_sample_button_dispose(GObject* object) {
+	JammoSampleButton* sample_button;
+	
+	sample_button = JAMMO_SAMPLE_BUTTON(object);
+
+	if (sample_button->priv->sequencer) {
+		g_object_remove_weak_pointer(G_OBJECT(sample_button->priv->sequencer), (gpointer*)&sample_button->priv->sequencer);
+		sample_button->priv->sequencer = NULL;
+	}
+
 	G_OBJECT_CLASS(jammo_sample_button_parent_class)->dispose(object);
 }
 
@@ -398,6 +414,17 @@ static void jammo_sample_button_class_init(JammoSampleButtonClass* sample_button
 	                                "A text that is displayed on top of the button",
 	                                NULL,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoSampleButton:sequencer:
+	 *
+	 * A sequencer that is used to track tempo and pitch until the underlying sample is added to an editing track. See JammoSample::sequencer .
+	 */
+	g_object_class_install_property(gobject_class, PROP_SEQUENCER,
+	                                g_param_spec_object("sequencer",
+	                                "Sequencer",
+	                                "A sequencer that is used to track tempo and pitch until the underlying sample is added to an editing track",
+	                                JAMMO_TYPE_SEQUENCER,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	/**
 	 * JammoSampleButton::listened:
@@ -448,3 +475,15 @@ static void on_size_change(ClutterTexture* texture, gint width, gint height, gpo
 	
 	tangle_actor_set_aspect_ratio(TANGLE_ACTOR(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(sample_button))), width / height);
 }
+
+static void set_sequencer(JammoSampleButton* sample_button, JammoSequencer* sequencer) {
+	if (sample_button->priv->sequencer != sequencer) {
+		if (sample_button->priv->sequencer) {
+			g_object_remove_weak_pointer(G_OBJECT(sample_button->priv->sequencer), (gpointer*)&sample_button->priv->sequencer);
+		}
+		sample_button->priv->sequencer = sequencer;
+		if (sample_button->priv->sequencer) {
+			g_object_add_weak_pointer(G_OBJECT(sample_button->priv->sequencer), (gpointer*)&sample_button->priv->sequencer);
+		}
+	}
+}
