@@ -169,7 +169,11 @@ static gboolean jammo_track_view_is_dragging_droppable(TangleDroppableActor* dro
 	
 	if (JAMMO_IS_SAMPLE_BUTTON(dragging->draggable_actor) &&
 	    clutter_actor_transform_stage_point(CLUTTER_ACTOR(track_view), dragging->center_x, dragging->center_y, &center_x, &center_y)) {
-		n_slots = (guint)(clutter_actor_get_width(CLUTTER_ACTOR(dragging->draggable_actor)) / track_view->priv->real_slot_width + 0.5);
+
+		guint64 duration_of_one_slot= track_view->priv->slot_duration;
+		guint64 duration_of_sample = jammo_sample_get_duration(jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(dragging->draggable_actor)));
+		n_slots = (guint) ((double)duration_of_sample / (double) duration_of_one_slot + 0.5);
+
 		center_x -= (n_slots - 1) * track_view->priv->real_slot_width / 2;
 		slot = center_x / track_view->priv->real_slot_width;
 
@@ -258,7 +262,9 @@ static gboolean jammo_track_view_handle_dropping(TangleDroppableActor* droppable
 	ClutterActor* copy_of_sample_button;
 	guint slot;
 	guint n_slots;
-	
+	guint64 duration_of_one_slot;
+	guint64 duration_of_sample;
+
 	track_view = JAMMO_TRACK_VIEW(droppable_actor);
 	widget = TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(track_view)));
 	
@@ -280,7 +286,10 @@ static gboolean jammo_track_view_handle_dropping(TangleDroppableActor* droppable
 
 		jammo_sample_button_set_background_color(JAMMO_SAMPLE_BUTTON(copy_of_sample_button), &track_view->priv->sample_color);
 
-		n_slots = (guint)(clutter_actor_get_width(CLUTTER_ACTOR(dragging->draggable_actor)) / track_view->priv->real_slot_width + 0.5);
+		duration_of_one_slot = track_view->priv->slot_duration;
+		duration_of_sample = jammo_sample_get_duration(jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(dragging->draggable_actor)));
+		n_slots = (guint) ((double)duration_of_sample / (double) duration_of_one_slot + 0.5);
+
 		center_x -= (n_slots - 1) * track_view->priv->real_slot_width / 2;
 		slot = center_x / track_view->priv->real_slot_width;
 
@@ -290,6 +299,7 @@ static gboolean jammo_track_view_handle_dropping(TangleDroppableActor* droppable
 		clutter_actor_set_x(copy_of_sample_button, x - dragging->anchor_x);
 		clutter_actor_set_y(copy_of_sample_button, y - dragging->anchor_y);
 		clutter_actor_set_height(copy_of_sample_button, track_view->priv->slot_height);
+		clutter_actor_set_width(copy_of_sample_button, n_slots * track_view->priv->slot_width);
 		tangle_widget_add(widget, copy_of_sample_button, NULL);
 
 		clutter_actor_animate(copy_of_sample_button, CLUTTER_EASE_OUT_CUBIC, 300, "x", slot * track_view->priv->real_slot_width, "y", 0.0, NULL);
@@ -693,7 +703,10 @@ static gboolean check_if_overlapping(JammoTrackView* track_view, ClutterActor* s
 	gfloat x;
 	
 	widget = TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(track_view)));
-	n_slots = (guint)(clutter_actor_get_width(sample_button) / track_view->priv->real_slot_width + 0.5);
+	guint64 duration_of_one_slot= track_view->priv->slot_duration;
+	guint64 duration_of_sample = jammo_sample_get_duration(jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(sample_button)));
+	n_slots = (guint) ((double)duration_of_sample / (double) duration_of_one_slot + 0.5);
+
 	for (children = tangle_widget_get_children_readonly(widget); children; children = children->next) {
 		actor = CLUTTER_ACTOR(children->data);
 		x = clutter_actor_get_x(actor);
