@@ -25,6 +25,7 @@
 #include "configure.h"
 
 //used for commandline starting
+#include "3-6gui/chum.h"
 #include "7-12gui/midi_editor.h"
 #include "7-12gui/sequencer.h"
 #include "7-12gui/startmenu.h"
@@ -323,6 +324,7 @@ int main(int argc, char** argv) {
 
 	if (!strcmp(application_name,"jammo3_6")) { //start jammo 3-6 years
 		printf("Starting 3-6 years game\n");
+		g_timeout_add(10, start_3_6_game,NULL);
 		g_timeout_add(10000, door_timeouts,NULL); //10 seconds and door will be opened automatically
 	}
 
@@ -357,6 +359,7 @@ int main(int argc, char** argv) {
 			start_communitymenu();
 		}
 		else { //Do not use this with commandline parameters
+			g_timeout_add(10, start_3_6_game,NULL);
 			g_timeout_add(10000, door_timeouts,NULL); //10 seconds and door will be opened automatically
 		}
 	}
