@@ -94,6 +94,8 @@ enum
   PROP_CAN_ACTIVATE_PULL,
 	PROP_RECORDING,
 	PROP_EVENTLIST,
+	PROP_TEMPO_SCALE,
+	PROP_PITCH_SHIFT,
   PROP_LAST
 };
 
@@ -329,6 +331,14 @@ static void gst_jammo_slider_class_init (GstJammoSliderClass * klass)
   g_object_class_install_property (gobject_class, PROP_EVENTLIST,
       g_param_spec_pointer ("eventlist", "A list of events",
           "Get or set a list of events", G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+  g_object_class_install_property (gobject_class, PROP_TEMPO_SCALE,
+      g_param_spec_float ("tempo-scale", "Tempo scale", "Tempo scale factor of playback mode",
+      		0.0, 5.0, 1.0,
+          G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_STATIC_STRINGS));
+  g_object_class_install_property (gobject_class, PROP_PITCH_SHIFT,
+      g_param_spec_int ("pitch-shift", "Pitch shift", "Pitch shift of produced sound",
+      		-12, 12, 0,
+          G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_STATIC_STRINGS));
   gstbasesrc_class->set_caps = GST_DEBUG_FUNCPTR (gst_jammo_slider_setcaps);
   gstbasesrc_class->is_seekable =
       GST_DEBUG_FUNCPTR (gst_jammo_slider_is_seekable);
@@ -364,6 +374,9 @@ static void gst_jammo_slider_init (GstJammoSlider * src, GstJammoSliderClass * g
   src->sustain = DEFAULT_SUSTAIN;
   src->release = DEFAULT_RELEASE;
 
+	src->pitch_shift=0;
+	src->tempo_scale=1.0;
+
 	// by default slider records
 	src->recording=TRUE;
 
@@ -508,7 +521,6 @@ gst_jammo_slider_dispose (GObject * object)
 		g_free(src->blow_table);
 		src->blow_table=NULL;
 	}
-
 	if (src->sine_table) {
 		g_free(src->sine_table);
 		src->sine_table=NULL;
@@ -524,7 +536,6 @@ gst_jammo_slider_dispose (GObject * object)
 	if (src->eventlist) {
 		jammo_slider_event_free_glist(&(src->eventlist));
 	}
-
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
@@ -659,22 +670,22 @@ static void do_playback_process(GstJammoSlider * src){
 		}
 	timestamp = event->timestamp;
 
-	while (src->time > timestamp){
-		printf("DEBUG: gstjammoslider: delayed: %llu ms, freq: %f, type: %d\n",(unsigned long long) (src->time - timestamp)/1000/1000, event->freq, event->type);
-		gfloat freq=event->freq;
+	while (src->time * src->tempo_scale > timestamp){
+		printf("DEBUG: gstjammoslider: delayed: %llu ms, freq: %f, type: %d\n",(unsigned long long) ((src->time * src->tempo_scale - timestamp)/src->tempo_scale)/1000/1000, event->freq, event->type);
+		gfloat freq=event->freq * pitch(src->pitch_shift);
 
 		if (freq >= MINFREQ && freq <= MAXFREQ) {
 			if (event->type==JAMMO_SLIDER_EVENT_ON ) {
-				process_slider_event_on(src, event->freq);
+				process_slider_event_on(src, freq);
 			}
 
 			else if (event->type==JAMMO_SLIDER_EVENT_OFF) {
-				process_slider_event_off(src, event->freq);
+				process_slider_event_off(src, freq);
 			}
 
 			else if (event->type==JAMMO_SLIDER_EVENT_MOTION) {
 				if (src->state==TRUE) {
-					process_slider_event_motion(src, event->freq);
+					process_slider_event_motion(src, freq);
 				}
 			}
 			else {
@@ -1243,14 +1254,14 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
 				timestamp = src->time;
 
 				if (event->type==JAMMO_SLIDER_EVENT_ON) {
-					process_slider_event_on(src, event->freq);
+					process_slider_event_on(src, event->freq * pitch(src->pitch_shift));
 				}
 				else if (event->type==JAMMO_SLIDER_EVENT_OFF) {
-					process_slider_event_off(src, event->freq);
+					process_slider_event_off(src, event->freq * pitch(src->pitch_shift));
 				}
 				else if (event->type==JAMMO_SLIDER_EVENT_MOTION) {
 					if (src->state==TRUE) {
-						process_slider_event_motion(src, event->freq);
+						process_slider_event_motion(src, event->freq * pitch(src->pitch_shift));
 						// check if event can be discarded
 						if (src->previous_event.type==JAMMO_SLIDER_EVENT_MOTION &&
 							timestamp - src->time_of_last_stored_event < DISCARDTIME) {
@@ -1315,6 +1326,12 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
 				jammo_slider_event_store_event_to_glist(&(src->eventlist), n->freq, n->type, n->timestamp);
         }
 			break;
+    case PROP_TEMPO_SCALE:
+      src->tempo_scale = g_value_get_float (value);
+      break;
+    case PROP_PITCH_SHIFT:
+      src->pitch_shift = g_value_get_int (value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -1366,6 +1383,12 @@ static void gst_jammo_slider_get_property (GObject * object, guint prop_id,
 		case PROP_EVENTLIST:
 			g_value_set_pointer (value, src->eventlist);
 			break;
+		case PROP_TEMPO_SCALE:
+			g_value_set_float (value, src->tempo_scale);
+			break;
+		case PROP_PITCH_SHIFT:
+			g_value_set_int (value, src->pitch_shift);
+			break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
