@@ -16,11 +16,16 @@ G_DEFINE_TYPE(JammoBackingTrack, jammo_backing_track, JAMMO_TYPE_PLAYING_TRACK);
 
 enum {
 	PROP_0,
-	PROP_FILENAME
+	PROP_FILENAME,
+	PROP_REAL_FILENAME
 };
 
 struct _JammoBackingTrackPrivate {
 	gchar* filename;
+	gchar* real_filename;
+	guint tempo;
+	gchar* pitch;
+	GstElement* source;
 	guint64 duration;
 };
 
@@ -31,6 +36,7 @@ typedef struct {
 
 static void on_new_decoded_pad(GstElement* element, GstPad* pad, gboolean last, gpointer data);
 static void preroll(JammoBackingTrack* backing_track);
+static void setup_source(JammoBackingTrack* backing_track);
 
 JammoBackingTrack* jammo_backing_track_new(const gchar* filename) {
 
@@ -63,6 +69,9 @@ static void jammo_backing_track_get_property(GObject* object, guint prop_id, GVa
 		case PROP_FILENAME:
 			g_value_set_string(value, backing_track->priv->filename);
 			break;
+		case PROP_REAL_FILENAME:
+			g_value_set_string(value, backing_track->priv->filename);
+			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -74,9 +83,31 @@ static guint64 jammo_backing_track_get_duration(JammoTrack* track) {
 	return JAMMO_BACKING_TRACK(track)->priv->duration;
 }
 
+static void jammo_backing_track_set_tempo(JammoTrack* track, guint tempo) {
+	JammoBackingTrack* backing_track;
+	
+	backing_track = JAMMO_BACKING_TRACK(track);
+
+	if (backing_track->priv->tempo != tempo) {
+		backing_track->priv->tempo = tempo;
+		setup_source(backing_track);	
+	}
+}
+
+static void jammo_backing_track_set_pitch(JammoTrack* track, const gchar* pitch) {
+	JammoBackingTrack* backing_track;
+	
+	backing_track = JAMMO_BACKING_TRACK(track);
+
+	if (g_strcmp0(backing_track->priv->pitch, pitch)) {
+		g_free(backing_track->priv->pitch);
+		backing_track->priv->pitch = g_strdup(pitch);
+		setup_source(backing_track);
+	}
+}
+
 static GstElement* jammo_backing_track_setup_playing_element(JammoPlayingTrack* playing_track, GstBin* bin) {
 	JammoBackingTrack* backing_track;
-	GstElement* source;
 	GstElement* decodebin;
 	GstElement* convert;
 	
@@ -84,17 +115,17 @@ static GstElement* jammo_backing_track_setup_playing_element(JammoPlayingTrack*
 
 	g_return_val_if_fail(backing_track->priv->filename, NULL);
 
-	preroll(backing_track);
+	backing_track->priv->source = gst_element_factory_make("filesrc", NULL);
+	setup_source(backing_track);
 
-	source = gst_element_factory_make("filesrc", NULL);
-	g_object_set(source, "location", backing_track->priv->filename, NULL);
+	preroll(backing_track);
 
 	decodebin = gst_element_factory_make("decodebin", NULL);
 	convert = gst_element_factory_make("audioconvert", NULL);
 	g_signal_connect(decodebin, "new-decoded-pad", G_CALLBACK(on_new_decoded_pad), convert);
 
-	gst_bin_add_many(bin, source, decodebin, convert, NULL);
-	gst_element_link(source, decodebin);
+	gst_bin_add_many(bin, backing_track->priv->source, decodebin, convert, NULL);
+	gst_element_link(backing_track->priv->source, decodebin);
 
 	return convert;
 }
@@ -123,6 +154,8 @@ static void jammo_backing_track_class_init(JammoBackingTrackClass* backing_track
 	gobject_class->get_property = jammo_backing_track_get_property;
 
 	track_class->get_duration = jammo_backing_track_get_duration;
+	track_class->set_tempo = jammo_backing_track_set_tempo;
+	track_class->set_pitch = jammo_backing_track_set_pitch;
 	playing_track_class->setup_playing_element = jammo_backing_track_setup_playing_element;
 
 	/**
@@ -134,6 +167,15 @@ static void jammo_backing_track_class_init(JammoBackingTrackClass* backing_track
 	                                "The file name of the played audio",
 	                                NULL,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoBackingTrack:real-filename:
+	 */
+	g_object_class_install_property(gobject_class, PROP_REAL_FILENAME,
+	                                g_param_spec_string("real-filename",
+	                                "Real file name",
+	                                "The real file name of the played audio after the parameters have been parsed",
+	                                NULL,
+	                                G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private(gobject_class, sizeof(JammoBackingTrackPrivate));
 }
@@ -205,7 +247,7 @@ static void preroll(JammoBackingTrack* backing_track) {
 	gst_object_unref(bus);
 
 	filesrc = gst_element_factory_make("filesrc", NULL);
-	g_object_set(filesrc, "location", backing_track->priv->filename, NULL);
+	g_object_set(filesrc, "location", backing_track->priv->real_filename, NULL);
 	decodebin = gst_element_factory_make("decodebin", NULL);
 	sink = gst_element_factory_make("fakesink", NULL);
 	gst_bin_add_many(GST_BIN(preroll_data->pipeline), filesrc, decodebin, sink, NULL);
@@ -214,3 +256,64 @@ static void preroll(JammoBackingTrack* backing_track) {
 
 	gst_element_set_state(preroll_data->pipeline, GST_STATE_PLAYING); 
 }
+
+static gchar* str_replace(gchar* string, gsize position, gsize length, const gchar* replacement, gchar** replacement_end_return) {
+	gsize string_length;
+	gsize replacement_length;
+	gchar* s;
+	
+	string_length = strlen(string);
+	replacement_length = strlen(replacement);
+	s = (gchar*)g_malloc(string_length - length + replacement_length + 1);
+	g_memmove(s, string, position);
+	g_memmove(s + position, replacement, replacement_length);
+	g_memmove(s + position + replacement_length, string + position + length, string_length - position - length + 1);
+
+	if (replacement_end_return) {
+		*replacement_end_return = s + position + replacement_length;
+	}
+
+	g_free(string);
+
+	return s;
+}
+
+static void setup_source(JammoBackingTrack* backing_track) {
+	gchar* filename;
+	gchar* s;
+	gchar* tempo_string;
+	
+	if (backing_track->priv->source) {
+		filename = s = g_strdup(backing_track->priv->filename);
+		while ((s = strchr(s, '$'))) {
+			switch (s[1]) {
+				case '$':
+					filename = str_replace(filename, s - filename, 2, "$", &s);
+					break;
+				case 't':
+					tempo_string = g_strdup_printf("%u", backing_track->priv->tempo);
+					filename = str_replace(filename, s - filename, 2, tempo_string, &s);
+					g_free(tempo_string);
+					break;
+				case 'p':
+					filename = str_replace(filename, s - filename, 2, (backing_track->priv->pitch ? backing_track->priv->pitch : "?"), &s);
+					break;
+				default:
+					g_warning("Unexpected parameter in the backing track filename: '$%c', skipped.", s[1]);
+					s += 2;
+					break;
+			}
+		}
+
+		if (g_strcmp0(backing_track->priv->real_filename, filename)) {
+			g_free(backing_track->priv->real_filename);
+			backing_track->priv->real_filename = filename;
+
+			g_object_set(backing_track->priv->source, "location", backing_track->priv->real_filename, NULL);
+		} else {
+			g_free(filename);
+		}
+	}
+}
+
+
