@@ -13,6 +13,10 @@
 #include "jammo-meam-private.h"
 #include <sys/time.h>
 
+// default tempo for calculating tempo scale for element
+// value does not matter but there has to be a reference tempo
+#define DEFAULT_TEMPO 110.0
+
 G_DEFINE_TYPE(JammoSliderTrack, jammo_slider_track, JAMMO_TYPE_PLAYING_TRACK);
 
 enum {
@@ -63,7 +67,7 @@ static void jammo_slider_track_set_property(GObject* object, guint prop_id, cons
 	switch (prop_id) {
 		case PROP_SLIDER_TYPE:
 			slider_track->priv->slider_type = g_value_get_int(value);
-			printf("set_property: slider=%d \n",g_value_get_int(value));
+			printf("jammo_slider_track_set_property: slider_type=%d \n",slider_track->priv->slider_type);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -122,13 +126,52 @@ static gboolean jammo_slider_track_receive_message(JammoTrack* track, GstMessage
 	return retvalue;
 }
 
+static void jammo_slider_track_set_tempo(JammoTrack* track, guint tempo) {
+	JammoSliderTrack* slider_track;
+	gfloat tempo_scale;
+	
+	slider_track = JAMMO_SLIDER_TRACK(track);
+
+	if (tempo==0) {
+		tempo_scale=1.0;
+	}
+	else {
+		tempo_scale=(gfloat)tempo / DEFAULT_TEMPO;
+	}
+	g_object_set(slider_track->priv->slider, "tempo-scale", tempo_scale, NULL);
+	
+}
+
+static void jammo_slider_track_set_pitch(JammoTrack* track, const gchar* pitch) {
+	JammoSliderTrack* slider_track;
+	gint pitch_shift=0;
+	
+	slider_track = JAMMO_SLIDER_TRACK(track);
+	if (pitch==NULL) pitch_shift=0;
+	else if (strcmp(pitch, "C")==0) pitch_shift=0;
+	else if (strcmp(pitch, "C#")==0) pitch_shift=1;
+	else if (strcmp(pitch, "D")==0) pitch_shift=2;
+	else if (strcmp(pitch, "D#")==0) pitch_shift=3;
+	else if (strcmp(pitch, "E")==0) pitch_shift=4;
+	else if (strcmp(pitch, "F")==0) pitch_shift=5;
+	else if (strcmp(pitch, "F#")==0) pitch_shift=6;
+	else if (strcmp(pitch, "G")==0) pitch_shift=7;
+	else if (strcmp(pitch, "G#")==0) pitch_shift=8;
+	else if (strcmp(pitch, "A")==0) pitch_shift=9;
+	else if (strcmp(pitch, "A#")==0) pitch_shift=10;
+	else if (strcmp(pitch, "B")==0) pitch_shift=11;
+	else pitch_shift=0;
+	
+	g_object_set(slider_track->priv->slider, "pitch-shift", pitch_shift, NULL);	
+}
+
 static GstElement* jammo_slider_track_setup_playing_element(JammoPlayingTrack* playing_track, GstBin* bin) {
 	JammoSliderTrack* slider_track;
 
 	slider_track = JAMMO_SLIDER_TRACK(playing_track);
 
 	int slider_nro = slider_track->priv->slider_type;
-	printf ("Type of slider is: %d\n",slider_nro);
+	printf ("jammo_slider_track_setup_playing_element: slider_type is: %d\n",slider_nro);
 	
 	slider_track->priv->slider = gst_element_factory_make("jammoslider", NULL);
 	// slider track has a reference to slider
@@ -182,6 +225,8 @@ static void jammo_slider_track_class_init(JammoSliderTrackClass* slider_track_cl
 
 	track_class->get_duration = jammo_slider_track_get_duration;
 	track_class->set_offline = jammo_slider_track_set_offline;
+	track_class->set_pitch = jammo_slider_track_set_pitch;
+	track_class->set_tempo = jammo_slider_track_set_tempo;
 	playing_track_class->setup_playing_element = jammo_slider_track_setup_playing_element;
 	gobject_class->finalize = jammo_slider_track_finalize;
 	gobject_class->dispose = jammo_slider_track_dispose;
